@@ -24,8 +24,7 @@ int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    MainWindow mw;
-    mw.show();
+    MainWindow::instance()->show();
 
     return app.exec();
 }
